automata.fsm

Finite state transducer library. Intended for data representations of state transitions, leaving actions to consumers of the library.

Finite state transducer library. Intended for data representations of
state transitions, leaving actions to consumers of the library.
raw docstring

automata.view

Simplistic visualization builder. Leaves calling graphviz tools up to the caller

Simplistic visualization builder. Leaves calling
graphviz tools up to the caller
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries